Pytest-Fantasy
=================

|build-status| |coverage|


Pytest plugin for Flask Fantasy Framework.

.. note::

    THIS PROJECT IS ON DEVELOPMENT. DON'T USE IT.




.. |build-status| image:: https://secure.travis-ci.org/wangwenpei/pytest-fantasy.png?branch=master
    :alt: Build status
    :target: https://travis-ci.org/wangwenpei/pytest-fantasy

.. |coverage| image:: https://codecov.io/github/wangwenpei/pytest-fantasy/coverage.svg?branch=master
    :target: https://codecov.io/github/wangwenpei/pytest-fantasy?branch=master

